import sys

from ..api import utils

import fuc
import pysam

description = f"""
Create a BED file which contains all regions used by PyPGx.
"""

def create_parser(subparsers):
    parser = fuc.api.common._add_parser(
        subparsers,
        fuc.api.common._script_name(),
        description=description,
        help=
"""Create a BED file which contains all regions used by
PyPGx."""
    )
    parser.add_argument(
        '--assembly',
        metavar='TEXT',
        default='GRCh37',
        help=
"""Reference genome assembly (default: 'GRCh37')
(choices: 'GRCh37', 'GRCh38')."""
    )
    parser.add_argument(
        '--add-chr-prefix',
        action='store_true',
        help=
"""Whether to add the 'chr' string in contig names."""
    )
    parser.add_argument(
        '--merge',
        action='store_true',
        help=
"""Whether to merge overlapping intervals (gene names will
be removed too)."""
    )
    parser.add_argument(
        '--sv-genes',
        action='store_true',
        help=
"""Whether to only return genes with SV."""
    )

def main(args):
    bf = utils.create_regions_bed(
        assembly=args.assembly, add_chr_prefix=args.add_chr_prefix,
        merge=args.merge, sv_genes=args.sv_genes
    )
    sys.stdout.write(bf.to_string())



import sys

from ..api import utils

import fuc
import pysam

description = f"""
Train CNV caller for target gene.

This command will return a SVM-based multiclass classifier that makes CNV
calls using the one-vs-rest strategy.
"""

def create_parser(subparsers):
    parser = fuc.api.common._add_parser(
        subparsers,
        fuc.api.common._script_name(),
        description=description,
        help=
"""Train CNV caller for target gene."""
    )
    parser.add_argument(
        'copy_number',
        metavar='copy-number',
        help=
"""Input archive file with the semantic type
CovFrame[CopyNumber]."""
    )
    parser.add_argument(
        'cnv_calls',
        metavar='cnv-calls',
        help=
"""Input archive file with the semantic type
SampleTable[CNVCalls]."""
    )
    parser.add_argument(
        'cnv_caller',
        metavar='cnv-caller',
        help=
"""Output archive file with the semantic type Model[CNV]."""
    )
    parser.add_argument(
        '--confusion-matrix',
        metavar='PATH',
        help=
"""Write the confusion matrix as a CSV file where rows
indicate actual class and columns indicate prediction
class."""
    )

def main(args):
    result = utils.train_cnv_caller(
        args.copy_number, args.cnv_calls,
        confusion_matrix=args.confusion_matrix
    )
    result.to_file(args.cnv_caller)
